@@ -10,7 +10,7 @@
         or type java2html --help for options list
 
 	written by
-	Lorenzo Bettini <lorenzo.bettini@penteres.it>
+	Lorenzo Bettini <bettini@gnu.org>
 	http://w3.newnet.it/bettini
 	http://www.gnu.org/software/java2html
  */
@@ -25,7 +25,7 @@ public class Hello {
     String xml = "<tag attr=\"value\">&auml;</tag>", foo2 = "\\" ;
     
     public static void main( String args[] ) {
-	// just some greetings ;-)
+	// just some greetings ;-)  /*
 	System.out.println( "Hello from java2html :-)" ) ;
 	System.out.println( "\tby Lorenzo Bettini" ) ;
 	System.out.println( "\tlorenzo.bettini@penteres.it" ) ;
